==> zbxe.beta.0.2.1.tgz: zbxe/modules/widget/lang/es.lang.php <==
<?php
    /**
     * @archivo   modules/widget/lang/es.lang.php
     * @autor zero <zero@nzeo.com>
     * @sumario Paquete del idioma español para el módulo Widget (básico)
     **/

    $lang->cmd_generate_code = 'Generar Código';

    $lang->widget_name = 'Nombre de Widget';
    $lang->widget_maker = 'Desarrollador de Widget';
    $lang->widget_history = 'Actualizar la historia';
    $lang->widget_info = 'información de Widget';
    $lang->widget_code = 'Código';
    $lang->widget_cache = 'Cache';

    $lang->widget_fix_width = 'Ancho permanente';
    $lang->widget_width = 'Ancho';
    $lang->widget_position = 'Posición';
    $lang->widget_position_none = 'Próxima línea';
    $lang->widget_position_left = 'Izquierdo';
    $lang->widget_position_right = 'Derecho';
    $lang->widget_margin = 'Márgen';
    $lang->widget_margin_top = 'Márgen superior';
    $lang->widget_margin_right = 'Márgen derecho';
    $lang->widget_margin_bottom = 'Márgen inferior';
    $lang->widget_margin_left= 'Márgen izquierdo';
    $lang->about_widget_fix_width = 'Si selecciona esta opción el ancho será permanente.';
    $lang->about_widget_width = 'Ingrese el ancho de Widget.';
    $lang->about_widget_position = 'Selecciona la posición si desea mostra más widgets en una línea.';
    $lang->about_widget_margin = "Uste puede ingresar el márgen de los widgets : superior, inferior, derecho e izquierdo.";
    $lang->about_widget_cache = 'Se puede usar datos de caché creado durante el tiempo asignado.';

    $lang->generated_code = 'Generar códigos';

    $lang->msg_widget_is_not_exists = 'No existe widget %s .';
    $lang->msg_widget_object_is_null = 'No puede ser creado el objeto de widget %s.';
    $lang->msg_widget_proc_is_null = 'No puede ser ejecutado el proc() de widget %s.';

    $lang->about_widget_code = 'Ingrese primero los valores requeridos, luego presiona el botón "Generar códigos" para mostrar el código en el espacio inferior para ser añadido en el archivo de los temas.';
    $lang->about_widget_code_in_page = 'Luego de ingresar los valores requeridos, presiona el botón "Añadir" para insertar el código de widget dentro de la página.';
    $lang->about_addon = "Un Widget es una pequena aplicación para ser usados en los diseños o en el módulo de páginas.\n Puede ser enlazados con un módulo interno o con open api externo y con la configuración de ella puede utilizar en variadas aplicaciones.\nSin la necesidad de utilizar los módulos de página o del diseño de Zeroboard XE, Usted puede directamente añadir un widget usando la función de [Generar Códigos].";
?>

==> zbxe.beta.0.2.7.tgz: zbxe/modules/widget/lang/es.lang.php <==
<?php
    /**
     * @archivo   modules/widget/lang/es.lang.php
     * @autor zero <zero@nzeo.com>
     * @sumario Paquete del idioma español para el módulo Widget (básico)
     **/

    $lang->cmd_generate_code = 'Generar Código';

    $lang->widget_name = 'Nombre de Widget';
    $lang->widget_maker = 'Desarrollador de Widget';
    $lang->widget_history = 'Actualizar la historia';
    $lang->widget_info = 'información de Widget';
    $lang->widget_code = 'Código';
    $lang->widget_cache = 'Cache';

    $lang->widget_fix_width = 'Ancho permanente';
    $lang->widget_width = 'Ancho';
    $lang->widget_position = 'Posición';
    $lang->widget_position_none = 'Próxima línea';
    $lang->widget_position_left = 'Izquierdo';
    $lang->widget_position_right = 'Derecho';
    $lang->widget_margin = 'Márgen';
    $lang->widget_margin_top = 'Márgen superior';
    $lang->widget_margin_right = 'Márgen derecho';
    $lang->widget_margin_bottom = 'Márgen inferior';
    $lang->widget_margin_left= 'Márgen izquierdo';
    $lang->about_widget_fix_width = 'Si selecciona esta opción el ancho será permanente.';
    $lang->about_widget_width = 'Ingrese el ancho de Widget.';
    $lang->about_widget_position = 'Selecciona la posición si desea mostra más widgets en una línea.';
    $lang->about_widget_margin = "Uste puede ingresar el márgen de los widgets : superior, inferior, derecho e izquierdo.";
    $lang->about_widget_cache = 'Se puede usar datos de caché creado durante el tiempo asignado.';

    $lang->generated_code = 'Generar códigos';

    $lang->msg_widget_is_not_exists = 'No existe widget %s .';
    $lang->msg_widget_object_is_null = 'No puede ser creado el objeto de widget %s.';
    $lang->msg_widget_proc_is_null = 'No puede ser ejecutado el proc() de widget %s.';

    $lang->about_widget_code = 'Ingrese primero los valores requeridos, luego presiona el botón "Generar códigos" para mostrar el código en el espacio inferior para ser añadido en el archivo de los temas.';
    $lang->about_widget_code_in_page = 'Luego de ingresar los valores requeridos, presiona el botón "Añadir" para insertar el código de widget dentro de la página.';
    $lang->about_widget = "Un Widget es una pequena aplicación para ser usados en los diseños o en el módulo de páginas.\n Puede ser enlazados con un módulo interno o con open api externo y con la configuración de ella puede utilizar en variadas aplicaciones.\nSin la necesidad de utilizar los módulos de página o del diseño de Zeroboard XE, Usted puede directamente añadir un widget usando la función de [Generar Códigos].";

    $lang->cmd_content_insert = "내용 직접 추가";
    $lang->cmd_box_widget_insert = "상자 위젯 추가";
    $lang->cmd_remove_all_widgets  = "내용 모두 지우기";

    $lang->cmd_widget_size = "위젯 크기";
    $lang->cmd_widget_align = "위젯 정렬";
    $lang->cmd_widget_align_left = "왼쪽";
    $lang->cmd_widget_align_right = "오른쪽";
    $lang->cmd_widget_margin = "외부 여백";
    $lang->cmd_widget_padding = "내부 여백";
    $lang->cmd_widget_border = "위젯 테두리";
    $lang->cmd_widget_border_solid = "실선";
    $lang->cmd_widget_border_dotted = "점선";
    $lang->cmd_widget_background_color = "배경색";
    $lang->cmd_widget_background_image_url = "배경 이미지";
    $lang->cmd_widget_background_image_repeat = "반복";
    $lang->cmd_widget_background_image_no_repeat = "고정";
    $lang->cmd_widget_background_image_x_repeat = "가로 반복";
    $lang->cmd_widget_background_image_y_repeat = "세로 반복";
    $lang->cmd_widget_background_image_x = "가로 위치";
    $lang->cmd_widget_background_image_y = "세로 위치";
?>
